@@ -32,6 +32,8 @@ render <- function(input,
   init_render_context()
   on.exit(clear_render_context(), add = TRUE)
 
+  on.exit(clean_tmpfiles(), add = TRUE)
+
   # check for "all" output formats
   if (identical(output_format, "all")) {
     output_format <- enumerate_output_formats(input, envir, encoding)
@@ -240,7 +242,7 @@ render <- function(input,
   output_dir <- dirname(output_file)
 
   # use output filename based files dir
-  files_dir <-file.path(output_dir, knitr_files_dir(basename(output_file)))
+  files_dir <- file.path(output_dir, knitr_files_dir(basename(output_file)))
   files_dir <- pandoc_path_arg(files_dir)
 
   # default to no cache_dir (may be generated by the knit)
@@ -257,8 +259,13 @@ render <- function(input,
   }
 
   # reset knit_meta (and ensure it's always reset before exiting render)
-  knit_meta_reset()
-  on.exit(knit_meta_reset(), add = TRUE)
+  old_knit_meta <- knit_meta_reset()
+  on.exit({
+    knit_meta_reset()
+    if (length(old_knit_meta)) {
+      knitr::knit_meta_add(old_knit_meta, attr(old_knit_meta, 'knit_meta_id'))
+    }
+  }, add = TRUE)
 
   # presume that we're rendering as a static document unless specified
   # otherwise in the parameters
@@ -342,10 +349,11 @@ render <- function(input,
       knitr::opts_knit$set(root.dir = root_dir)
 
     # use filename based figure and cache directories
-    figures_dir <- paste(files_dir, "/figure-", pandoc_to, "/", sep = "")
-    knitr::opts_chunk$set(fig.path=figures_dir)
-    cache_dir <-knitr_cache_dir(input, pandoc_to)
-    knitr::opts_chunk$set(cache.path=cache_dir)
+    base_pandoc_to <- gsub('[-+].*', '', pandoc_to)
+    figures_dir <- paste(files_dir, "/figure-", base_pandoc_to, "/", sep = "")
+    knitr::opts_chunk$set(fig.path = figures_dir)
+    cache_dir <- knitr_cache_dir(input, base_pandoc_to)
+    knitr::opts_chunk$set(cache.path = cache_dir)
 
     # strip the trailing slash from cache_dir so that file.exists() and unlink()
     # check on it later works on windows
@@ -354,7 +362,7 @@ render <- function(input,
     # merge user options and hooks
     if (!is.null(output_format$knitr)) {
       knitr::opts_knit$set(as.list(output_format$knitr$opts_knit))
-      knitr::opts_chunk$set(as.list(output_format$knitr$opts_chunk))
+      knitr::opts_chunk$set(adjust_dev(as.list(output_format$knitr$opts_chunk)))
       knitr::opts_template$set(as.list(output_format$knitr$opts_template))
       knitr::knit_hooks$set(as.list(output_format$knitr$knit_hooks))
       knitr::opts_hooks$set(as.list(output_format$knitr$opts_hooks))
@@ -560,22 +568,20 @@ render <- function(input,
 
     need_bibtex <- grepl('[.](pdf|tex)$', output_file) &&
       any(c('--natbib', '--biblatex') %in% output_format$pandoc$args)
-    # if we are running citeproc then explicitly forward the bibliography
-    # on the command line (works around pandoc-citeproc issue whereby yaml
-    # strings that begin with numbers are interpreted as numbers)
-    if ((is.null(yaml_front_matter$citeproc) || yaml_front_matter$citeproc) && !is.null(bibliography <- yaml_front_matter$bibliography)) {
-      # remove the .bib extension since it does not work with MikTeX's BibTeX
-      if (need_bibtex && is_windows()) bibliography <- sub('[.]bib$', '', bibliography)
-      output_format$pandoc$args <- c(
-        output_format$pandoc$args,
-        rbind("--bibliography", pandoc_path_arg(bibliography, FALSE))
-      )
-    }
 
     perf_timer_start("pandoc")
 
     convert <- function(output, citeproc = FALSE) {
 
+      # temporarily move figures to the intermediate dir if specified:
+      # https://github.com/rstudio/rmarkdown/issues/500
+      figures_dir <- gsub('/$', '', knitr::opts_chunk$get("fig.path"))
+      if (!is.null(intermediates_dir) && dir_exists(figures_dir)) {
+        figures_dir_tmp <- intermediates_loc(figures_dir)
+        move_dir(figures_dir, figures_dir_tmp)
+        on.exit(move_dir(figures_dir_tmp, figures_dir), add = TRUE)
+      }
+
       # ensure we expand paths (for Windows where leading `~/` does
       # not get expanded by pandoc)
       utf8_input <- path.expand(utf8_input)
@@ -604,10 +610,7 @@ render <- function(input,
       pandoc_output_tmp <- basename(tempfile("pandoc", tmpdir = getwd(), fileext = ext))
 
       # clean up temporary file on exit
-      on.exit({
-        if (file.exists(pandoc_output_tmp))
-          unlink(pandoc_output_tmp)
-      }, add = TRUE)
+      on.exit(unlink(pandoc_output_tmp), add = TRUE)
 
       # call pandoc to render file
       status <- pandoc_convert(
@@ -652,7 +655,8 @@ render <- function(input,
       # have references in the input)
       run_citeproc <- citeproc_required(yaml_front_matter, input_lines)
       # generate .tex if we want to keep the tex source
-      if (output_format$pandoc$keep_tex) convert(texfile, run_citeproc)
+      if (texfile != output_file && output_format$pandoc$keep_tex)
+        convert(texfile, run_citeproc)
       # run the main conversion if the output file is not .tex
       convert(output_file, run_citeproc)
     }
@@ -690,11 +694,7 @@ render <- function(input,
 
   # write markdown output if requested
   if (output_format$keep_md && !md_input) {
-
-    md <- c(md_header_from_front_matter(yaml_front_matter),
-            partition_yaml_front_matter(input_text)$body)
-
-    writeLines(md, file_with_ext(output_file, "md"), useBytes = TRUE)
+    file.copy(input, file_with_ext(output_file, "md"), overwrite = TRUE)
   }
 
   if (run_pandoc) {
@@ -756,24 +756,6 @@ knit_meta_reset <- function(class = NULL) {
   knitr::knit_meta(class, clean = TRUE)
 }
 
-md_header_from_front_matter <- function(front_matter) {
-
-  md <- c()
-
-  if (!is.null(front_matter$title))
-    md <- c(md, paste("# ", front_matter$title, sep = ""))
-
-  if (is.character(front_matter$author)) {
-    authors <- paste(front_matter$author, "  ", sep = "")
-    md <- c(md, authors)
-  }
-
-  if (!is.null(front_matter$date))
-    md <- c(md, paste(front_matter$date, "  ", sep = ""))
-
-  md
-}
-
 # render context (render-related state can be stuffed here)
 .render_context <- NULL # initialized in .onLoad
 render_context <- function() {
@@ -808,7 +790,7 @@ id_prefix_from_args <- function(args) {
   for (i in 1:length(args)) {
     arg <- args[[i]]
     if (identical(arg, "--id-prefix") && (i < length(args)))
-      return (args[[i+1]])
+      return(args[[i + 1]])
   }
 
   # default to empty string
