@@ -3,23 +3,27 @@
 #'
 #' Format for converting from R Markdown to a slidy presentation.
 #'
-#' @inheritParams beamer_presentation
 #' @inheritParams pdf_document
 #' @inheritParams html_document
+#' @inheritParams beamer_presentation
 #'
 #' @param duration Duration (in minutes) of the slide deck. This value is used
 #'   to add a countdown timer to the slide footer.
 #' @param footer Footer text (e.g. organization name and/or copyright)
-#' @param font_adjustment Increase or decrease the default font size
-#'  (e.g. -1 or +1). You can also manually adjust the font size during the
-#'  presentation using the 'S' (smaller) and 'B' (bigger) keys.
+#' @param font_adjustment Increase or decrease the default font size (e.g. -1 or
+#'   +1). You can also manually adjust the font size during the presentation
+#'   using the 'S' (smaller) and 'B' (bigger) keys.
+#' @param ... Additional function arguments to pass to the base R Markdown HTML
+#'   output formatter \code{\link{html_document_base}}
 #'
 #' @return R Markdown output format to pass to \code{\link{render}}
 #'
 #' @details
 #'
-#' See the \href{http://rmarkdown.rstudio.com/slidy_presentation_format.html}{online
-#' documentation} for additional details on using the \code{slidy_presentation} format.
+#' See the
+#' \href{http://rmarkdown.rstudio.com/slidy_presentation_format.html}{online
+#' documentation} for additional details on using the \code{slidy_presentation}
+#' format.
 #'
 #' For more information on markdown syntax for presentations see the
 #' \href{http://pandoc.org/README.html}{pandoc online documentation}.
@@ -93,6 +97,8 @@ slidy_presentation <- function(incremental = FALSE,
     args <- c(args, pandoc_variable_arg("font-size-adjustment",
                                         font_adjustment))
 
+  md_extensions <- smart_extension(smart, md_extensions)
+
   # content includes
   args <- c(args, includes_to_pandoc_args(includes))
 
